![](docs/repo-hero.png)
# **SayPy**
An extremely pointless yet friendly Python package. Was created for purpose of deploying and creating a package end to end testing out some new DevOps methods.

## **Getting Started**
From the command line
```python
    pip install saypy
    saypy
```
**or**

from a python script
```python
    from saypy import say_hi
    say_hi('Matt')
```

## **Feature requests?**
Probably not going to be addding too many features, but if there is request please open issue!